@@ -69,7 +69,7 @@ def get_player_suffix(name):
         player_r = get(f'https://www.basketball-reference.com{suffix}')
     while player_r.status_code==200:
         player_soup = BeautifulSoup(player_r.content, 'html.parser')
-        h1 = player_soup.find('h1', attrs={'itemprop': 'name'})
+        h1 = player_soup.find('h1')
         if h1:
             page_name = h1.find('span').text
             """
@@ -85,10 +85,19 @@ def get_player_suffix(name):
                 page_first_name = page_names[0]
                 if first_name.lower() == page_first_name.lower():
                     return suffix
-                other_names_search.pop(0)
-                last_name_part = create_last_name_part_of_suffix(other_names_search)
-                initial = last_name_part[0].lower()
-                suffix = '/players/'+initial+'/'+last_name_part+first_name_part+'01.html'
+                # if players have same first two letters of last name then just
+                # increment suffix
+                elif first_name.lower()[:2] == page_first_name.lower()[:2]:
+                    player_number = int(''.join(c for c in suffix if c.isdigit())) + 1
+                    if player_number < 10:
+                        player_number = f"0{str(player_number)}"
+                    suffix = f"/players/{initial}/{last_name_part}{first_name_part}{player_number}.html"
+                else:
+                    other_names_search.pop(0)
+                    last_name_part = create_last_name_part_of_suffix(other_names_search)
+                    initial = last_name_part[0].lower()
+                    suffix = '/players/'+initial+'/'+last_name_part+first_name_part+'01.html'
+
                 player_r = get(f'https://www.basketball-reference.com{suffix}')
 
     return None
